OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Jūsų kliento programa nėra įgaliota prisijungti. Informuokite administratorių apie savo kliento programą.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Jūsų nukreipimo adresas (redirect URL) turi būti pilnas, pavyzdžiui: https://jusuadresas.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "OAuth 2.0 clients" : "OAuth 2.0 klientai",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 leidžia išorinėms tarnyboms užklausti prieigą prie {instanceName}.",
    "Name" : "Pavadinimas",
    "Redirection URI" : "Peradresavimo URI",
    "Client Identifier" : "Kliento identifikatorius",
    "Secret key" : "Slaptasis raktas",
    "Add client" : "Pridėti klientą",
    "Add" : "Pridėti",
    "Delete" : "Ištrinti"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
